Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: webkit/support/webkit_support.cc

Issue 11359217: Move scoped_temp_dir from base to base/files (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/support/webkit_support.h ('k') | webkit/tools/test_shell/simple_file_system.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/support/webkit_support.cc
diff --git a/webkit/support/webkit_support.cc b/webkit/support/webkit_support.cc
index 96f507b07a217961f315705b3c2b210c632b853b..8c4446eb60179e3f158ab76401c9caa46925b356 100644
--- a/webkit/support/webkit_support.cc
+++ b/webkit/support/webkit_support.cc
@@ -13,6 +13,7 @@
#include "base/debug/stack_trace.h"
#include "base/file_path.h"
#include "base/file_util.h"
+#include "base/files/scoped_temp_dir.h"
#include "base/i18n/icu_util.h"
#include "base/logging.h"
#include "base/memory/ref_counted.h"
@@ -20,7 +21,6 @@
#include "base/message_loop.h"
#include "base/path_service.h"
#include "base/process_util.h"
-#include "base/scoped_temp_dir.h"
#include "base/string_piece.h"
#include "base/string_util.h"
#include "base/stringprintf.h"
@@ -36,13 +36,13 @@
#include "net/base/net_errors.h"
#include "net/base/net_util.h"
#include "testing/gtest/include/gtest/gtest.h"
+#include "third_party/WebKit/Source/WebKit/chromium/public/platform/WebURLError.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebCache.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebFileSystemCallbacks.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebKit.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebPluginParams.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebStorageNamespace.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebView.h"
-#include "third_party/WebKit/Source/WebKit/chromium/public/platform/WebURLError.h"
#if defined(TOOLKIT_GTK)
#include "ui/base/keycodes/keyboard_code_conversion_gtk.h"
#endif
@@ -710,7 +710,7 @@ WebURL LocalFileToDataURL(const WebURL& fileUrl) {
return WebURL(GURL(kDataUrlPrefix + contents_base64));
}
// A wrapper object for exporting ScopedTempDir to be used
// by webkit layout tests.
class ScopedTempDirectoryInternal : public ScopedTempDirectory {
public:
@@ -723,7 +723,7 @@ class ScopedTempDirectoryInternal : public ScopedTempDirectory {
}
private:
- ScopedTempDir tempDirectory_;
+ base::ScopedTempDir tempDirectory_;
};
ScopedTempDirectory* CreateScopedTempDirectory() {
« no previous file with comments | « webkit/support/webkit_support.h ('k') | webkit/tools/test_shell/simple_file_system.h » ('j') | no next file with comments »
@@ -710,7 +710,7 @@ WebURL LocalFileToDataURL(const WebURL& fileUrl) {
return WebURL(GURL(kDataUrlPrefix + contents_base64));
}
-// A wrapper object for exporting ScopedTempDir to be used
+// A wrapper object for exporting base::ScopedTempDir to be used
// by webkit layout tests.
class ScopedTempDirectoryInternal : public ScopedTempDirectory {

Powered by Google App Engine
This is Rietveld 408576698